@@ -51,10 +51,18 @@ test_that("phrase returns as expected", {
 
   expect_equal(.notesub("ees", simplify = TRUE), "es")
   expect_identical(p("a", 1), p("a", 1, NA))
+  expect_identical(
+    p("c d e f g a b c'", 8, bar = NULL),
+    p("c d e f g a b c'", 8, bar = FALSE)
+  )
   expect_identical(
     p("c d e f g a b c'", 8),
     gsub(" \\|$", "", p("c d e f g a b c'", 8, bar = TRUE))
   )
+  expect_identical(
+    p("c d e f g a b c'", 8),
+    gsub(" \\\\bar \"\\|\\.\"$", "", p("c d e f g a b c'", 8, bar = "|."))
+  )
 })
 
 p1 <- phrase("c ec'g' ec'g'", "4 4 2") # no explicit strings (not recommended)
